@@ -1,20 +1,17 @@
-from functools import reduce
 import sys
 import warnings
+from functools import reduce
 
 import pandas as pd
 from pyomo.dae import *
 from pyomo.environ import *
 
+from kipet.common.VisitorClasses import ScalingVisitor
 from kipet.core_methods.ResultsObject import *
 from kipet.core_methods.Simulator import *
-from kipet.post_model_build.pyomo_model_tools import (
-    index_set_info,
-    get_index_sets,
-    )
-from kipet.common.VisitorClasses import ScalingVisitor
 from kipet.dev_tools.display import Print
-
+from kipet.post_model_build.pyomo_model_tools import (get_index_sets,
+                                                      index_set_info)
 from kipet.top_level.variable_names import VariableNames
 
 __var = VariableNames()
@@ -182,8 +179,8 @@ class PyomoSimulator(Simulator):
     def fix_from_trajectory(self, variable_name, variable_index, trajectories, verbose=False):
 
         if variable_name in  self.__var.modeled_states:
-            
-            raise NotImplementedError("Fixing state variables is not allowd. Only algebraics can be fixed")
+            pass
+            # raise NotImplementedError("Fixing state variables is not allowd. Only algebraics can be fixed")
 
         single_traj = trajectories[variable_index]
         sim_alltimes = sorted(self._alltimes)
